"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Kafka = require("node-rdkafka");
class KafkaProducer {
    constructor(conf, topicConf = {}) {
        this.ready = false;
        this.producer = new Kafka.Producer(conf, topicConf);
        this.producer.on('event.error', err => {
            console.error(err);
        });
    }
    connect(metadataOptions = {}) {
        return new Promise((resolve, reject) => {
            this.producer.connect(metadataOptions, (err, data) => {
                if (err) {
                    reject(err);
                }
            });
            return this.producer.on('ready', () => {
                this.ready = true;
                resolve();
            });
        });
    }
    produce(topic, partition, message, key, timestamp, opaque) {
        if (!this.ready) {
            throw new Error('Connection Not Ready');
        }
        return new Promise((resolve, reject) => {
            try {
                this.producer.produce(topic, partition, new Buffer(message), key, timestamp, opaque);
                resolve();
            }
            catch (err) {
                reject(err);
            }
        });
    }
}
exports.KafkaProducer = KafkaProducer;
class KafkaConsumer {
    constructor(conf, topicConf = {}) {
        this.ready = false;
        this.buffer = [];
        this.mode = null;
        this.consumer = new Kafka.KafkaConsumer(conf, topicConf);
    }
    connect(metadataOptions = {}) {
        return new Promise((resolve, reject) => {
            this.consumer.connect(metadataOptions, (err, data) => {
                if (err) {
                    reject(err);
                }
            });
            return this.consumer.on('ready', () => {
                this.ready = true;
                resolve();
            });
        });
    }
    subscribe(topics) {
        return this.consumer.subscribe(topics);
    }
    unsubscribe() {
        return this.consumer.unsubscribe();
    }
    flowing(cb) {
        if (this.mode != null) {
            throw Error(`Consumer has been set as ${this.mode} mode`);
        }
        this.mode = 'flowing';
        return this.consumer.consume(cb, null);
    }
    fetch() {
        if (this.mode != null) {
            throw Error(`Consumer has been set as ${this.mode} mode`);
        }
        return new Promise((resolve, reject) => {
            return this.consumer.consume(1, (err, message) => {
                if (err) {
                    reject(err);
                }
                return resolve(message);
            });
        });
    }
}
exports.KafkaConsumer = KafkaConsumer;
exports.default = {
    KafkaProducer,
    KafkaConsumer,
};
//# sourceMappingURL=index.js.map